@@ -5,7 +5,7 @@ from .webhandler import webhandler
 
 
 class repository(package_manager, parser, webhandler):
-    """An object for interaction with all parts of a libget repository."""
+    """An object for interacting with all parts of a libget repository."""
 
     def __init__(
         self,
